@@ -45,7 +45,7 @@ bool TrojitaImportData::importMails()
 
 bool TrojitaImportData::importSettings()
 {
-    const QString settingsPath = mPath + QLatin1String("trojita.conf");
+    const QString settingsPath = mPath + QLatin1StringView("trojita.conf");
     TrojitaSettings settings(settingsPath);
     settings.setAbstractDisplayInfo(mAbstractDisplayInfo);
     settings.importSettings();
@@ -54,7 +54,7 @@ bool TrojitaImportData::importSettings()
 
 bool TrojitaImportData::importAddressBook()
 {
-    const QString addressbookPath = QDir::homePath() + QLatin1String("/.abook/addressbook");
+    const QString addressbookPath = QDir::homePath() + QLatin1StringView("/.abook/addressbook");
     TrojitaAddressBook addressBooks(addressbookPath);
     addressBooks.setAbstractDisplayInfo(mAbstractDisplayInfo);
     addressBooks.readAddressBook();
